@@ -10,7 +10,7 @@ pub async fn index(req: Request<State>) -> tide::Result<Response> {
         .new_wrapper()
         .eq("private", false)
         .order_by(false, &["create_time"]);
-    let pastes = match pool.fetch_list_by_wrapper(&wrapper).await {
+    let pastes = match pool.fetch_list_by_wrapper(wrapper).await {
         Ok(pastes) => pastes,
         Err(_err) => vec![],
     };
